@@ -209,7 +209,7 @@ class TableFiller(FillerBase):
                     elif self.__provider__.is_relation(self.__entity__, field) and value is not None:
                         value = self._get_relation_value(field, value)
                     elif self.__provider__.is_binary(self.__entity__, field) and value is not None:
-                        value = '<file>'
+                        value = '&lt;file&gt;'
                 row[field] = unicode(value)
             rows.append(row)
         return rows
@@ -248,4 +248,4 @@ class AddFormFiller(FormFiller):
     def get_value(self, values=None, **kw):
         """xxx: get the server/entity defaults."""
         kw = super(AddFormFiller, self).get_value(values, **kw)
-        return self.__provider__.get_default_values(self.__entity__, params=values)
\ No newline at end of file
+        return self.__provider__.get_default_values(self.__entity__, params=values)
