@@ -5,12 +5,20 @@ from tw.dojo.selectshuttle import DojoSelectShuttleField, DojoSortedSelectShuttl
 from tw.api import JSSource
 from sprox.widgets import PropertyMixin
 
+from tw.dojo import DojoBase, tundragrid_css, tundra_css, dojo_css, dojo_js
+from tw.core import JSLink
+
+sprox_grid_js = JSLink(modname="sprox",
+                       filename="widgets/static/dojo_grid.js",
+                       )
+
 class SproxDojoGrid(DojoBase):
     engine_name=None
-    available_engines = ['mako','genshi']
-    css = [grid_css, tundragrid_css]
-    require = ['dojox.grid.DataGrid', 'dojox.data.QueryReadStore']
+    available_engines = ['mako', 'genshi']
+    css = [grid_css, tundragrid_css, tundra_css]
+    javascript=[dojo_js, sprox_grid_js]
     dojoType = 'dojox.grid.DataGrid'
+    require = ['dojox.grid.DataGrid', 'twdojo.data.TWDojoRestStore']
     params = ['id', 'attrs', 'columns', 'jsId', 'action',
               'rowsPerPage', 'model', 'delayScroll', 'cssclass', 'actions',
               'columnResizing', 'columnReordering', 'column_widths', 'default_column_width', 'headers','column_options', 'default_column_options','dojoStoreType','dojoStoreWidget'
@@ -25,7 +33,7 @@ class SproxDojoGrid(DojoBase):
     column_options = {}
     default_column_options = {}
     headers = {}
-    default_column_width = "10em"
+    default_column_width = "30px"
     include_dynamic_js_calls = True
     action='.json'
     model = None
@@ -33,6 +41,7 @@ class SproxDojoGrid(DojoBase):
     dojoStoreType = 'dojox.data.QueryReadStore'
     dojoStoreWidget = None
     template = "sprox.widgets.templates.dojogrid"
+    attrs = {'style':"height:200px"}
     def update_params(self,d):
         d['dojoStoreWidget']=DojoQueryReadStore()
         super(SproxDojoGrid, self).update_params(d)
